Configuration
=============

When first run, Abjad creates an ``.abjad`` directory in your own ``$HOME`` directory. 
In ``$HOME/.abjad`` you will find the Abjad configuration file: ``config.py``. 
Here you can tell Abjad about your preferred PDF file viewer, MIDI player, your preferred LilyPond language, etc. 
All relevant variables have defaults that you can change to suit your needs. 
In Linux, for example, you might want to set your ``pdfviewer`` to ``evince`` and your ``midiplayer`` to ``timidity``. 

``config.py`` is a regular Python file, so you should make sure the file follows Python syntax.


